"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildConfigFromConnections = buildConfigFromConnections;
exports.buildConnectionsDictFromList = buildConnectionsDictFromList;
exports.buildConfigString = buildConfigString;
function buildConfigFromConnections(connections) {
    const environments = getUniqueConnectionEnvs(connections);
    return {
        template_repository_version: "1.0.0",
        helpers: "src/templates/helpers.jsonata",
        environments: buildTemplateEnvironments(environments, connections),
    };
}
function buildConnectionsDictFromList(connections) {
    return connections.reduce((dict, conn) => {
        if (conn.name) {
            dict[conn.name] = {
                id: conn.id,
                slug: conn.slug,
                environment: conn.environment,
            };
        }
        return dict;
    }, {});
}
function getUniqueConnectionEnvs(connections) {
    return connections.reduce((envs, conn) => {
        if (!envs.includes(conn.environment))
            envs.push(conn.environment);
        return envs;
    }, []);
}
function buildTemplateEnvironments(environments, connections) {
    return environments.map((env) => {
        return {
            environment: env,
            templates: [
                {
                    connection_ids: connections
                        .filter((conn) => conn.environment === env)
                        .map((conn) => conn.id),
                    paths: {
                        item: "src/templates/item/item.jsonata",
                        variation: "src/templates/variation/variation.jsonata",
                        item_group: "src/templates/item_group/item_group.jsonata",
                        grouping: "src/templates/grouping/grouping.jsonata",
                        mapping: "src/templates/mapping/mapping.jsonata",
                    },
                },
            ],
        };
    });
}
function buildConfigString(config, connections) {
    let configString = JSON.stringify(config, null, 2);
    for (const connectionName in connections) {
        const conn = connections[connectionName];
        /**
         * We need to escape the name to ensure the JSON won't break, in case
         * there are special characters in the connection name.
         */
        const escapedName = JSON.stringify(connectionName);
        configString = configString.replace(`"${conn.id}"`, `connections[${escapedName}].id`);
    }
    return configString;
}
