"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTemplateFiles = getTemplateFiles;
const find_deep_files_1 = require("../helpers/find-deep-files");
/**
 * Get a prompt-ready list of template files in the user repository
 */
async function getTemplateFiles() {
    const files = getTemplatePaths("src/templates");
    const filteredFiles = files.filter((file) => file.endsWith(".jsonata") && !file.includes("helpers"));
    return filteredFiles.map((file) => ({
        name: file.replace("src/templates/", ""),
        value: file.replace("src/templates/", ""),
    }));
}
/**
 * @param typePath The full type path. E.g.
 * - src/templates/item
 * - src/templates/variation
 * @returns A list of template paths for the given type. E.g.
 * - src/templates/item/1.jsonata
 * - src/templates/item/2.jsonata
 */
function getTemplatePaths(typePath) {
    try {
        return (0, find_deep_files_1.findDeepFiles)(typePath);
    }
    catch (error) {
        if (error instanceof Error && error.message.includes("ENOENT")) {
            return [];
        }
        throw error;
    }
}
